@@ -6,7 +6,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2004-2022 Univention GmbH
+# Copyright 2004-2023 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -78,7 +78,7 @@ __all__ = [
 
 REPLOG_FILE = '/var/log/univention/config-registry.replog'
 
-_SHOW_EMPTY, _SHOW_DESCRIPTION, _SHOW_SCOPE, _SHOW_CATEGORIES, _SHOW_DEFAULT = (1 << _ for _ in range(5))
+_SHOW_EMPTY, _SHOW_DESCRIPTION, _SHOW_SCOPE, _SHOW_CATEGORIES, _SHOW_DEFAULT, _SHOW_TYPE = (1 << _ for _ in range(6))
 
 
 class UnknownKeyException(Exception):
@@ -183,6 +183,7 @@ def handler_set(args, opts={}, quiet=False):
 						else:
 							print('E: Invalid UCR type definition for type %r of %r, value %r not set' % (vinfo.get('type'), key, value), file=sys.stderr)
 							opts['exit_code'] = 1
+							opts.setdefault('type_def_error', []).append((key, vinfo.get('type'), value))
 							continue  # do not set value and continue with next element of for loop to be set
 					else:
 						if not validator.check(value):
@@ -190,7 +191,8 @@ def handler_set(args, opts={}, quiet=False):
 								print('W: Value %r incompatible for %r, but setting anyway' % (value, key), file=sys.stderr)
 							else:
 								print('E: Value %r incompatible for %r' % (value, key), file=sys.stderr)
-								opts['exit_code'] = 1
+								opts['exit_code'] = 2
+								opts.setdefault('type_errors', []).append((key, value))
 								continue  # do not set value and continue with next element of for loop to be set
 				changes[key] = value
 			else:
@@ -529,6 +531,13 @@ def variable_info_string(key, value, variable_info, scope=None, details=_SHOW_DE
 	if variable_info and _SHOW_DEFAULT & details:
 		info.append(' Default: ' + variable_info.get('default', '(not set)'))
 
+	if variable_info and _SHOW_TYPE & details:
+		try:
+			validator = Type(variable_info)
+			info.append(' Type: %s' % (validator,))
+		except ValueError as exc:
+			info.append(' Type: %s' % exc)
+
 	if (_SHOW_CATEGORIES | _SHOW_DESCRIPTION) & details:
 		info.append('')
 
@@ -552,7 +561,7 @@ def handler_info(args, opts={}):
 			yield variable_info_string(
 				arg, ucr.get(arg, None),
 				info.get_variable(arg),
-				details=_SHOW_EMPTY | _SHOW_DESCRIPTION | _SHOW_CATEGORIES | _SHOW_DEFAULT)
+				details=_SHOW_EMPTY | _SHOW_DESCRIPTION | _SHOW_CATEGORIES | _SHOW_DEFAULT | _SHOW_TYPE)
 		except UnknownKeyException as ex:
 			print(ex, file=sys.stderr)
 
@@ -579,7 +588,7 @@ def handler_help(args, opts={}, out=sys.stdout):
 	"""
 	print(u'''
 univention-config-registry: base configuration for UCS
-copyright (c) 2001-2022 Univention GmbH, Germany
+copyright (c) 2001-2023 Univention GmbH, Germany
 
 Syntax:
   univention-config-registry [options] <action> [options] [parameters]
